@@ -1,7 +1,7 @@
 """
 Type annotations for datasync service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/type_defs.html)
 
 Usage::
 
@@ -16,7 +16,6 @@ from datetime import datetime
 from typing import IO, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 from .literals import (
     AgentStatusType,
@@ -106,19 +105,14 @@ __all__ = (
     "Ec2ConfigTypeDef",
     "FilterRuleTypeDef",
     "HdfsNameNodeTypeDef",
-    "ListAgentsRequestListAgentsPaginateTypeDef",
     "ListAgentsRequestRequestTypeDef",
     "ListAgentsResponseTypeDef",
-    "ListLocationsRequestListLocationsPaginateTypeDef",
     "ListLocationsRequestRequestTypeDef",
     "ListLocationsResponseTypeDef",
-    "ListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "ListTaskExecutionsRequestListTaskExecutionsPaginateTypeDef",
     "ListTaskExecutionsRequestRequestTypeDef",
     "ListTaskExecutionsResponseTypeDef",
-    "ListTasksRequestListTasksPaginateTypeDef",
     "ListTasksRequestRequestTypeDef",
     "ListTasksResponseTypeDef",
     "LocationFilterTypeDef",
@@ -749,14 +743,6 @@ HdfsNameNodeTypeDef = TypedDict(
     },
 )
 
-ListAgentsRequestListAgentsPaginateTypeDef = TypedDict(
-    "ListAgentsRequestListAgentsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListAgentsRequestRequestTypeDef = TypedDict(
     "ListAgentsRequestRequestTypeDef",
     {
@@ -775,15 +761,6 @@ ListAgentsResponseTypeDef = TypedDict(
     },
 )
 
-ListLocationsRequestListLocationsPaginateTypeDef = TypedDict(
-    "ListLocationsRequestListLocationsPaginateTypeDef",
-    {
-        "Filters": Sequence["LocationFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListLocationsRequestRequestTypeDef = TypedDict(
     "ListLocationsRequestRequestTypeDef",
     {
@@ -803,28 +780,6 @@ ListLocationsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
-    "_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
-    {
-        "ResourceArn": str,
-    },
-)
-_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
-    "_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListTagsForResourceRequestListTagsForResourcePaginateTypeDef(
-    _RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
-    _OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
-):
-    pass
-
-
 _RequiredListTagsForResourceRequestRequestTypeDef = TypedDict(
     "_RequiredListTagsForResourceRequestRequestTypeDef",
     {
@@ -857,15 +812,6 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-ListTaskExecutionsRequestListTaskExecutionsPaginateTypeDef = TypedDict(
-    "ListTaskExecutionsRequestListTaskExecutionsPaginateTypeDef",
-    {
-        "TaskArn": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListTaskExecutionsRequestRequestTypeDef = TypedDict(
     "ListTaskExecutionsRequestRequestTypeDef",
     {
@@ -885,15 +831,6 @@ ListTaskExecutionsResponseTypeDef = TypedDict(
     },
 )
 
-ListTasksRequestListTasksPaginateTypeDef = TypedDict(
-    "ListTasksRequestListTasksPaginateTypeDef",
-    {
-        "Filters": Sequence["TaskFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListTasksRequestRequestTypeDef = TypedDict(
     "ListTasksRequestRequestTypeDef",
     {
